@@ -89,7 +89,7 @@ def test_should_handle_key_method_none_and_no_uri_attr():
     assert "/hls-key/key.bin" == third_segment_key['uri']
     assert "AES-128" == third_segment_key['method']
     assert "0X10ef8f758ca555115584bb5b3c687f52" == third_segment_key['iv']
-    assert "NONE" == data['segments'][6]['key']['method']  
+    assert "NONE" == data['segments'][6]['key']['method']
 
 def test_should_parse_title_from_playlist():
     data = m3u8.parse(playlists.SIMPLE_PLAYLIST_WITH_TITLE)
@@ -115,6 +115,28 @@ def test_should_parse_variant_playlist():
     assert 65000 == playlists_list[-1]['stream_info']['bandwidth']
     assert 'mp4a.40.5,avc1.42801e' == playlists_list[-1]['stream_info']['codecs']
 
+def test_should_parse_variant_playlist_with_cc_subtitles_and_audio():
+    data = m3u8.parse(playlists.VARIANT_PLAYLIST_WITH_CC_SUBS_AND_AUDIO)
+    playlists_list = list(data['playlists'])
+
+    assert True == data['is_variant']
+    assert None == data['media_sequence']
+    assert 2 == len(playlists_list)
+
+    assert 'http://example.com/with-cc-hi.m3u8' == playlists_list[0]['uri']
+    assert 1 == playlists_list[0]['stream_info']['program_id']
+    assert 7680000 == playlists_list[0]['stream_info']['bandwidth']
+    assert 'cc' == playlists_list[0]['stream_info']['closed_captions']
+    assert 'sub' == playlists_list[0]['stream_info']['subtitles']
+    assert 'aud' == playlists_list[0]['stream_info']['audio']
+
+    assert 'http://example.com/with-cc-low.m3u8' == playlists_list[-1]['uri']
+    assert 1 == playlists_list[-1]['stream_info']['program_id']
+    assert 65000 == playlists_list[-1]['stream_info']['bandwidth']
+    assert 'cc' == playlists_list[-1]['stream_info']['closed_captions']
+    assert 'sub' == playlists_list[-1]['stream_info']['subtitles']
+    assert 'aud' == playlists_list[-1]['stream_info']['audio']
+
 def test_should_parse_variant_playlist_with_average_bandwidth():
     data = m3u8.parse(playlists.VARIANT_PLAYLIST_WITH_AVERAGE_BANDWIDTH)
     playlists_list = list(data['playlists'])
@@ -287,3 +309,7 @@ def test_should_parse_start_with_precise():
     data = m3u8.parse(playlists.SIMPLE_PLAYLIST_WITH_START_PRECISE)
     assert data['start']['time_offset'] == 10.5
     assert data['start']['precise'] == 'YES'
+
+def test_simple_playlist_with_discontinuity_sequence():
+    data = m3u8.parse(playlists.SIMPLE_PLAYLIST_WITH_DISCONTINUITY_SEQUENCE)
+    assert data['discontinuity_sequence'] == 123
